#functions {
  color: #660000;
  width: 16;
  height: undefined("self");
  border-width: 5;
  variable: 11;
  background: linear-gradient(#000000, #ffffff);
}
#built-in {
  escaped: -Some::weird(#thing, y);
  lighten: #ffcccc;
  darken: #330000;
  saturate: #203c31;
  desaturate: #29332f;
  greyscale: #2e2e2e;
  spin-p: #bf6a40;
  spin-n: #bf4055;
  luma-white: 100%;
  luma-black: 0%;
  luma-black-alpha: 0%;
  luma-red: 21%;
  luma-green: 72%;
  luma-blue: 7%;
  luma-yellow: 93%;
  luma-cyan: 79%;
  luma-white-alpha: 50%;
  contrast-white: #000000;
  contrast-black: #ffffff;
  contrast-red: #ffffff;
  contrast-green: #000000;
  contrast-blue: #ffffff;
  contrast-yellow: #000000;
  contrast-cyan: #000000;
  contrast-light: #111111;
  contrast-dark: #eeeeee;
  contrast-light-thresh: #111111;
  contrast-dark-thresh: #eeeeee;
  contrast-high-thresh: #eeeeee;
  contrast-low-thresh: #111111;
  format: "rgb(32, 128, 64)";
  format-string: "hello world";
  format-multiple: "hello earth 2";
  format-url-encode: "red is %23ff0000";
  eformat: rgb(32, 128, 64);
  hue: 98;
  saturation: 12%;
  lightness: 95%;
  red: 255;
  green: 255;
  blue: 255;
  rounded: 11;
  rounded-two: 10.67;
  roundedpx: 3px;
  roundedpx-three: 3.333px;
  percentage: 20%;
  color: #ff0011;
  tint: #898989;
  tint-full: #ffffff;
  tint-percent: #898989;
  shade: #686868;
  shade-full: #000000;
  shade-percent: #686868;
  mix: #ff3300;
  mix-0: #ffff00;
  mix-100: #ff0000;
  mix-weightless: #ff8000;
}
#built-in .is-a {
  color: true;
  color1: true;
  color2: true;
  keyword: true;
  number: true;
  string: true;
  pixel: true;
  percent: true;
  em: true;
}
#alpha {
  alpha: rgba(153, 94, 51, 0.6);
}
#blendmodes {
  multiply: #ed0000;
  screen: #f600f6;
  overlay: #ed0000;
  softlight: #ff0000;
  hardlight: #0000ed;
  difference: #f600f6;
  exclusion: #f600f6;
  average: #7b007b;
  negation: #d73131;
}
