.mixin {
  border: 1px solid black;
}
.mixout {
  border-color: orange;
}
.borders {
  border-style: dashed;
}
#namespace .borders {
  border-style: dotted;
}
#namespace .biohazard {
  content: "death";
}
#namespace .biohazard .man {
  color: transparent;
}
#theme > .mixin {
  background-color: grey;
}
#container {
  color: black;
  border: 1px solid black;
  border-color: orange;
  background-color: grey;
}
#header .milk {
  color: white;
  border: 1px solid black;
  background-color: grey;
}
#header #cookie {
  border-style: dashed;
}
#header #cookie .chips {
  border-style: dotted;
}
#header #cookie .chips .calories {
  color: black;
  border: 1px solid black;
  border-color: orange;
  background-color: grey;
}
.secure-zone {
  color: transparent;
}
.direct {
  border-style: dotted;
}
.bo,
.bar {
  width: 100%;
}
.bo {
  border: 1px;
}
.ar.bo.ca {
  color: black;
}
.jo.ki {
  background: none;
}
.extended {
  width: 100%;
  border: 1px;
  background: none;
}
.foo .bar {
  width: 100%;
}
.underParents {
  color: red;
}
.parent .underParents {
  color: red;
}
* + h1 {
  margin-top: 25px;
}
legend + h1 {
  margin-top: 0;
}
h1 + * {
  margin-top: 10px;
}
* + h2 {
  margin-top: 20px;
}
legend + h2 {
  margin-top: 0;
}
h2 + * {
  margin-top: 8px;
}
* + h3 {
  margin-top: 15px;
}
legend + h3 {
  margin-top: 0;
}
h3 + * {
  margin-top: 5px;
}
.error {
  background-image: "/a.png";
  background-position: center center;
}
