.parens {
  border: 2px solid #000000;
  margin: 1px 3px 16 3;
  width: 36;
  padding: 2px 36px;
}
.more-parens {
  padding: 8 4 4 4px;
  width: 96;
  height: 113;
  margin: 12;
}
.nested-parens {
  width: 71;
  height: 6;
}
.mixed-units {
  margin: 2px 4em 1 5pc;
  padding: 6px 1em 2px 2;
}
