@import url("import/import-test-a.less");
@import url(http://fonts.googleapis.com/css?family=Open+Sans);

@import url(something.css) screen and (color) and (max-width: 600px);

#import-test {
  .mixin;
  width: 10px;
  height: @a + 10%;
}
@import "import/import-test-e" screen and (max-width: 600px);
