.tiny-scope {
  color: #998899;
}
.scope1 {
  color: #0000ff;
  border-color: #000000;
}
.scope1 .scope2 {
  color: #0000ff;
}
.scope1 .scope2 .scope3 {
  color: #ff0000;
  border-color: #000000;
  background-color: #ffffff;
}
