.mixin_import1() {
    @media all {
        .tst {
            color: black;
            @media screen {
                color: red;
                .tst3 {
                    color: white;
                }
            }
        }
    }
}

.mixin_import2() {
    .tst2 {
        color: white;
    }
}

.tst3 {
    color: grey;
}