.class {
  border: 1;
  boxer: 1;
  border: 2 !important;
  boxer: 2 !important;
  border: 3;
  boxer: 3;
  border: 4 !important;
  boxer: 4 !important;
  border: 5;
  boxer: 5;
  border: 0 !important;
  boxer: 0 !important;
  border: 9 !important;
  border: 9;
  boxer: 9;
}
